# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class IncidentDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'process_definition_id': 'str',
        'process_instance_id': 'str',
        'execution_id': 'str',
        'incident_timestamp': 'datetime',
        'incident_type': 'str',
        'activity_id': 'str',
        'failed_activity_id': 'str',
        'cause_incident_id': 'str',
        'root_cause_incident_id': 'str',
        'configuration': 'str',
        'tenant_id': 'str',
        'incident_message': 'str',
        'job_definition_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'process_definition_id': 'processDefinitionId',
        'process_instance_id': 'processInstanceId',
        'execution_id': 'executionId',
        'incident_timestamp': 'incidentTimestamp',
        'incident_type': 'incidentType',
        'activity_id': 'activityId',
        'failed_activity_id': 'failedActivityId',
        'cause_incident_id': 'causeIncidentId',
        'root_cause_incident_id': 'rootCauseIncidentId',
        'configuration': 'configuration',
        'tenant_id': 'tenantId',
        'incident_message': 'incidentMessage',
        'job_definition_id': 'jobDefinitionId'
    }

    def __init__(self, id=None, process_definition_id=None, process_instance_id=None, execution_id=None, incident_timestamp=None, incident_type=None, activity_id=None, failed_activity_id=None, cause_incident_id=None, root_cause_incident_id=None, configuration=None, tenant_id=None, incident_message=None, job_definition_id=None, local_vars_configuration=None):  # noqa: E501
        """IncidentDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._process_definition_id = None
        self._process_instance_id = None
        self._execution_id = None
        self._incident_timestamp = None
        self._incident_type = None
        self._activity_id = None
        self._failed_activity_id = None
        self._cause_incident_id = None
        self._root_cause_incident_id = None
        self._configuration = None
        self._tenant_id = None
        self._incident_message = None
        self._job_definition_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if process_definition_id is not None:
            self.process_definition_id = process_definition_id
        if process_instance_id is not None:
            self.process_instance_id = process_instance_id
        if execution_id is not None:
            self.execution_id = execution_id
        self.incident_timestamp = incident_timestamp
        if incident_type is not None:
            self.incident_type = incident_type
        if activity_id is not None:
            self.activity_id = activity_id
        if failed_activity_id is not None:
            self.failed_activity_id = failed_activity_id
        if cause_incident_id is not None:
            self.cause_incident_id = cause_incident_id
        if root_cause_incident_id is not None:
            self.root_cause_incident_id = root_cause_incident_id
        if configuration is not None:
            self.configuration = configuration
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if incident_message is not None:
            self.incident_message = incident_message
        if job_definition_id is not None:
            self.job_definition_id = job_definition_id

    @property
    def id(self):
        """Gets the id of this IncidentDto.  # noqa: E501

        The id of the incident.  # noqa: E501

        :return: The id of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IncidentDto.

        The id of the incident.  # noqa: E501

        :param id: The id of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def process_definition_id(self):
        """Gets the process_definition_id of this IncidentDto.  # noqa: E501

        The id of the process definition this incident is associated with.  # noqa: E501

        :return: The process_definition_id of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_id

    @process_definition_id.setter
    def process_definition_id(self, process_definition_id):
        """Sets the process_definition_id of this IncidentDto.

        The id of the process definition this incident is associated with.  # noqa: E501

        :param process_definition_id: The process_definition_id of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._process_definition_id = process_definition_id

    @property
    def process_instance_id(self):
        """Gets the process_instance_id of this IncidentDto.  # noqa: E501

        The id of the process instance this incident is associated with.  # noqa: E501

        :return: The process_instance_id of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._process_instance_id

    @process_instance_id.setter
    def process_instance_id(self, process_instance_id):
        """Sets the process_instance_id of this IncidentDto.

        The id of the process instance this incident is associated with.  # noqa: E501

        :param process_instance_id: The process_instance_id of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._process_instance_id = process_instance_id

    @property
    def execution_id(self):
        """Gets the execution_id of this IncidentDto.  # noqa: E501

        The id of the execution this incident is associated with.  # noqa: E501

        :return: The execution_id of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this IncidentDto.

        The id of the execution this incident is associated with.  # noqa: E501

        :param execution_id: The execution_id of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._execution_id = execution_id

    @property
    def incident_timestamp(self):
        """Gets the incident_timestamp of this IncidentDto.  # noqa: E501

        The time this incident happened. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The incident_timestamp of this IncidentDto.  # noqa: E501
        :rtype: datetime
        """
        return self._incident_timestamp

    @incident_timestamp.setter
    def incident_timestamp(self, incident_timestamp):
        """Sets the incident_timestamp of this IncidentDto.

        The time this incident happened. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param incident_timestamp: The incident_timestamp of this IncidentDto.  # noqa: E501
        :type: datetime
        """

        self._incident_timestamp = incident_timestamp

    @property
    def incident_type(self):
        """Gets the incident_type of this IncidentDto.  # noqa: E501

        The type of incident, for example: `failedJobs` will be returned in case of an incident which identified a failed job during the execution of a process instance. See the [User Guide](https://docs.camunda.org/manual/7.14/user-guide/process-engine/incidents/#incident-types) for a list of incident types.  # noqa: E501

        :return: The incident_type of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._incident_type

    @incident_type.setter
    def incident_type(self, incident_type):
        """Sets the incident_type of this IncidentDto.

        The type of incident, for example: `failedJobs` will be returned in case of an incident which identified a failed job during the execution of a process instance. See the [User Guide](https://docs.camunda.org/manual/7.14/user-guide/process-engine/incidents/#incident-types) for a list of incident types.  # noqa: E501

        :param incident_type: The incident_type of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._incident_type = incident_type

    @property
    def activity_id(self):
        """Gets the activity_id of this IncidentDto.  # noqa: E501

        The id of the activity this incident is associated with.  # noqa: E501

        :return: The activity_id of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_id

    @activity_id.setter
    def activity_id(self, activity_id):
        """Sets the activity_id of this IncidentDto.

        The id of the activity this incident is associated with.  # noqa: E501

        :param activity_id: The activity_id of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._activity_id = activity_id

    @property
    def failed_activity_id(self):
        """Gets the failed_activity_id of this IncidentDto.  # noqa: E501

        The id of the activity on which the last exception occurred.  # noqa: E501

        :return: The failed_activity_id of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._failed_activity_id

    @failed_activity_id.setter
    def failed_activity_id(self, failed_activity_id):
        """Sets the failed_activity_id of this IncidentDto.

        The id of the activity on which the last exception occurred.  # noqa: E501

        :param failed_activity_id: The failed_activity_id of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._failed_activity_id = failed_activity_id

    @property
    def cause_incident_id(self):
        """Gets the cause_incident_id of this IncidentDto.  # noqa: E501

        The id of the associated cause incident which has been triggered.  # noqa: E501

        :return: The cause_incident_id of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._cause_incident_id

    @cause_incident_id.setter
    def cause_incident_id(self, cause_incident_id):
        """Sets the cause_incident_id of this IncidentDto.

        The id of the associated cause incident which has been triggered.  # noqa: E501

        :param cause_incident_id: The cause_incident_id of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._cause_incident_id = cause_incident_id

    @property
    def root_cause_incident_id(self):
        """Gets the root_cause_incident_id of this IncidentDto.  # noqa: E501

        The id of the associated root cause incident which has been triggered.  # noqa: E501

        :return: The root_cause_incident_id of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._root_cause_incident_id

    @root_cause_incident_id.setter
    def root_cause_incident_id(self, root_cause_incident_id):
        """Sets the root_cause_incident_id of this IncidentDto.

        The id of the associated root cause incident which has been triggered.  # noqa: E501

        :param root_cause_incident_id: The root_cause_incident_id of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._root_cause_incident_id = root_cause_incident_id

    @property
    def configuration(self):
        """Gets the configuration of this IncidentDto.  # noqa: E501

        The payload of this incident.  # noqa: E501

        :return: The configuration of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this IncidentDto.

        The payload of this incident.  # noqa: E501

        :param configuration: The configuration of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._configuration = configuration

    @property
    def tenant_id(self):
        """Gets the tenant_id of this IncidentDto.  # noqa: E501

        The id of the tenant this incident is associated with.  # noqa: E501

        :return: The tenant_id of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this IncidentDto.

        The id of the tenant this incident is associated with.  # noqa: E501

        :param tenant_id: The tenant_id of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def incident_message(self):
        """Gets the incident_message of this IncidentDto.  # noqa: E501

        The message of this incident.  # noqa: E501

        :return: The incident_message of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._incident_message

    @incident_message.setter
    def incident_message(self, incident_message):
        """Sets the incident_message of this IncidentDto.

        The message of this incident.  # noqa: E501

        :param incident_message: The incident_message of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._incident_message = incident_message

    @property
    def job_definition_id(self):
        """Gets the job_definition_id of this IncidentDto.  # noqa: E501

        The job definition id the incident is associated with.  # noqa: E501

        :return: The job_definition_id of this IncidentDto.  # noqa: E501
        :rtype: str
        """
        return self._job_definition_id

    @job_definition_id.setter
    def job_definition_id(self, job_definition_id):
        """Sets the job_definition_id of this IncidentDto.

        The job definition id the incident is associated with.  # noqa: E501

        :param job_definition_id: The job_definition_id of this IncidentDto.  # noqa: E501
        :type: str
        """

        self._job_definition_id = job_definition_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IncidentDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IncidentDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.process_instance_query_dto import ProcessInstanceQueryDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestProcessInstanceQueryDto(unittest.TestCase):
    """ProcessInstanceQueryDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ProcessInstanceQueryDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.process_instance_query_dto.ProcessInstanceQueryDto()  # noqa: E501
        if include_optional :
            return ProcessInstanceQueryDto(
                deployment_id = '0', 
                process_definition_id = '0', 
                process_definition_key = '0', 
                process_definition_key_in = [
                    '0'
                    ], 
                process_definition_key_not_in = [
                    '0'
                    ], 
                business_key = '0', 
                business_key_like = '0', 
                case_instance_id = '0', 
                super_process_instance = '0', 
                sub_process_instance = '0', 
                super_case_instance = '0', 
                sub_case_instance = '0', 
                active = True, 
                suspended = True, 
                process_instance_ids = [
                    '0'
                    ], 
                with_incident = True, 
                incident_id = '0', 
                incident_type = '0', 
                incident_message = '0', 
                incident_message_like = '0', 
                tenant_id_in = [
                    '0'
                    ], 
                without_tenant_id = True, 
                process_definition_without_tenant_id = True, 
                activity_id_in = [
                    '0'
                    ], 
                root_process_instances = True, 
                leaf_process_instances = True, 
                variables = [
                    generic_camunda_client.models.variable_query_parameter_dto.VariableQueryParameterDto(
                        name = '0', 
                        operator = 'eq', 
                        value = generic_camunda_client.models.value.value(), )
                    ], 
                variable_names_ignore_case = True, 
                variable_values_ignore_case = True, 
                or_queries = [
                    generic_camunda_client.models.process_instance_query_dto.ProcessInstanceQueryDto(
                        deployment_id = '0', 
                        process_definition_id = '0', 
                        process_definition_key = '0', 
                        process_definition_key_in = [
                            '0'
                            ], 
                        process_definition_key_not_in = [
                            '0'
                            ], 
                        business_key = '0', 
                        business_key_like = '0', 
                        case_instance_id = '0', 
                        super_process_instance = '0', 
                        sub_process_instance = '0', 
                        super_case_instance = '0', 
                        sub_case_instance = '0', 
                        active = True, 
                        suspended = True, 
                        process_instance_ids = [
                            '0'
                            ], 
                        with_incident = True, 
                        incident_id = '0', 
                        incident_type = '0', 
                        incident_message = '0', 
                        incident_message_like = '0', 
                        tenant_id_in = [
                            '0'
                            ], 
                        without_tenant_id = True, 
                        process_definition_without_tenant_id = True, 
                        activity_id_in = [
                            '0'
                            ], 
                        root_process_instances = True, 
                        leaf_process_instances = True, 
                        variables = [
                            generic_camunda_client.models.variable_query_parameter_dto.VariableQueryParameterDto(
                                name = '0', 
                                operator = 'eq', 
                                value = generic_camunda_client.models.value.value(), )
                            ], 
                        variable_names_ignore_case = True, 
                        variable_values_ignore_case = True, 
                        sorting = [
                            generic_camunda_client.models.process_instance_query_dto_sorting.ProcessInstanceQueryDto_sorting(
                                sort_by = 'instanceId', 
                                sort_order = 'asc', )
                            ], )
                    ], 
                sorting = [
                    generic_camunda_client.models.process_instance_query_dto_sorting.ProcessInstanceQueryDto_sorting(
                        sort_by = 'instanceId', 
                        sort_order = 'asc', )
                    ]
            )
        else :
            return ProcessInstanceQueryDto(
        )

    def testProcessInstanceQueryDto(self):
        """Test ProcessInstanceQueryDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from generic_camunda_client.api_client import ApiClient
from generic_camunda_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class MetricsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_metrics(self, metrics_name, **kwargs):  # noqa: E501
        """get_metrics  # noqa: E501

        Retrieves the `sum` (count) for a given metric.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_metrics(metrics_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str metrics_name: The name of the metric. (required)
        :param datetime start_date: The start date (inclusive).
        :param datetime end_date: The end date (exclusive).
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MetricsResultDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_metrics_with_http_info(metrics_name, **kwargs)  # noqa: E501

    def get_metrics_with_http_info(self, metrics_name, **kwargs):  # noqa: E501
        """get_metrics  # noqa: E501

        Retrieves the `sum` (count) for a given metric.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_metrics_with_http_info(metrics_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str metrics_name: The name of the metric. (required)
        :param datetime start_date: The start date (inclusive).
        :param datetime end_date: The end date (exclusive).
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MetricsResultDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'metrics_name',
            'start_date',
            'end_date'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_metrics" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'metrics_name' is set
        if self.api_client.client_side_validation and ('metrics_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['metrics_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `metrics_name` when calling `get_metrics`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'metrics_name' in local_var_params:
            path_params['metrics-name'] = local_var_params['metrics_name']  # noqa: E501

        query_params = []
        if 'start_date' in local_var_params and local_var_params['start_date'] is not None:  # noqa: E501
            query_params.append(('startDate', local_var_params['start_date']))  # noqa: E501
        if 'end_date' in local_var_params and local_var_params['end_date'] is not None:  # noqa: E501
            query_params.append(('endDate', local_var_params['end_date']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/metrics/{metrics-name}/sum', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MetricsResultDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def interval(self, **kwargs):  # noqa: E501
        """interval  # noqa: E501

        Retrieves a list of metrics, aggregated for a given interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.interval(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: The name of the metric.
        :param str reporter: The name of the reporter (host), on which the metrics was logged. This will have value provided by the [hostname configuration property](https://docs.camunda.org/manual/7.14/reference/deployment-descriptors/tags/process-engine/#hostname).
        :param datetime start_date: The start date (inclusive).
        :param datetime end_date: The end date (exclusive).
        :param int first_result: Pagination of results. Specifies the index of the first result to return.
        :param int max_results: Pagination of results. Specifies the maximum number of results to return. Will return less results if there are no more results left.
        :param str interval: The interval for which the metrics should be aggregated. Time unit is seconds. Default: The interval is set to 15 minutes (900 seconds).
        :param str aggregate_by_reporter: Aggregate metrics by reporter.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[MetricsIntervalResultDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.interval_with_http_info(**kwargs)  # noqa: E501

    def interval_with_http_info(self, **kwargs):  # noqa: E501
        """interval  # noqa: E501

        Retrieves a list of metrics, aggregated for a given interval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.interval_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: The name of the metric.
        :param str reporter: The name of the reporter (host), on which the metrics was logged. This will have value provided by the [hostname configuration property](https://docs.camunda.org/manual/7.14/reference/deployment-descriptors/tags/process-engine/#hostname).
        :param datetime start_date: The start date (inclusive).
        :param datetime end_date: The end date (exclusive).
        :param int first_result: Pagination of results. Specifies the index of the first result to return.
        :param int max_results: Pagination of results. Specifies the maximum number of results to return. Will return less results if there are no more results left.
        :param str interval: The interval for which the metrics should be aggregated. Time unit is seconds. Default: The interval is set to 15 minutes (900 seconds).
        :param str aggregate_by_reporter: Aggregate metrics by reporter.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[MetricsIntervalResultDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name',
            'reporter',
            'start_date',
            'end_date',
            'first_result',
            'max_results',
            'interval',
            'aggregate_by_reporter'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method interval" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'reporter' in local_var_params and local_var_params['reporter'] is not None:  # noqa: E501
            query_params.append(('reporter', local_var_params['reporter']))  # noqa: E501
        if 'start_date' in local_var_params and local_var_params['start_date'] is not None:  # noqa: E501
            query_params.append(('startDate', local_var_params['start_date']))  # noqa: E501
        if 'end_date' in local_var_params and local_var_params['end_date'] is not None:  # noqa: E501
            query_params.append(('endDate', local_var_params['end_date']))  # noqa: E501
        if 'first_result' in local_var_params and local_var_params['first_result'] is not None:  # noqa: E501
            query_params.append(('firstResult', local_var_params['first_result']))  # noqa: E501
        if 'max_results' in local_var_params and local_var_params['max_results'] is not None:  # noqa: E501
            query_params.append(('maxResults', local_var_params['max_results']))  # noqa: E501
        if 'interval' in local_var_params and local_var_params['interval'] is not None:  # noqa: E501
            query_params.append(('interval', local_var_params['interval']))  # noqa: E501
        if 'aggregate_by_reporter' in local_var_params and local_var_params['aggregate_by_reporter'] is not None:  # noqa: E501
            query_params.append(('aggregateByReporter', local_var_params['aggregate_by_reporter']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/metrics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MetricsIntervalResultDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class MultiFormAttachmentDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attachment_name': 'str',
        'attachment_description': 'str',
        'attachment_type': 'str',
        'url': 'str',
        'content': 'file'
    }

    attribute_map = {
        'attachment_name': 'attachment-name',
        'attachment_description': 'attachment-description',
        'attachment_type': 'attachment-type',
        'url': 'url',
        'content': 'content'
    }

    def __init__(self, attachment_name=None, attachment_description=None, attachment_type=None, url=None, content=None, local_vars_configuration=None):  # noqa: E501
        """MultiFormAttachmentDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._attachment_name = None
        self._attachment_description = None
        self._attachment_type = None
        self._url = None
        self._content = None
        self.discriminator = None

        if attachment_name is not None:
            self.attachment_name = attachment_name
        if attachment_description is not None:
            self.attachment_description = attachment_description
        if attachment_type is not None:
            self.attachment_type = attachment_type
        if url is not None:
            self.url = url
        self.content = content

    @property
    def attachment_name(self):
        """Gets the attachment_name of this MultiFormAttachmentDto.  # noqa: E501

        The name of the attachment.  # noqa: E501

        :return: The attachment_name of this MultiFormAttachmentDto.  # noqa: E501
        :rtype: str
        """
        return self._attachment_name

    @attachment_name.setter
    def attachment_name(self, attachment_name):
        """Sets the attachment_name of this MultiFormAttachmentDto.

        The name of the attachment.  # noqa: E501

        :param attachment_name: The attachment_name of this MultiFormAttachmentDto.  # noqa: E501
        :type: str
        """

        self._attachment_name = attachment_name

    @property
    def attachment_description(self):
        """Gets the attachment_description of this MultiFormAttachmentDto.  # noqa: E501

        The description of the attachment.  # noqa: E501

        :return: The attachment_description of this MultiFormAttachmentDto.  # noqa: E501
        :rtype: str
        """
        return self._attachment_description

    @attachment_description.setter
    def attachment_description(self, attachment_description):
        """Sets the attachment_description of this MultiFormAttachmentDto.

        The description of the attachment.  # noqa: E501

        :param attachment_description: The attachment_description of this MultiFormAttachmentDto.  # noqa: E501
        :type: str
        """

        self._attachment_description = attachment_description

    @property
    def attachment_type(self):
        """Gets the attachment_type of this MultiFormAttachmentDto.  # noqa: E501

        The type of the attachment.  # noqa: E501

        :return: The attachment_type of this MultiFormAttachmentDto.  # noqa: E501
        :rtype: str
        """
        return self._attachment_type

    @attachment_type.setter
    def attachment_type(self, attachment_type):
        """Sets the attachment_type of this MultiFormAttachmentDto.

        The type of the attachment.  # noqa: E501

        :param attachment_type: The attachment_type of this MultiFormAttachmentDto.  # noqa: E501
        :type: str
        """

        self._attachment_type = attachment_type

    @property
    def url(self):
        """Gets the url of this MultiFormAttachmentDto.  # noqa: E501

        The url to the remote content of the attachment.  # noqa: E501

        :return: The url of this MultiFormAttachmentDto.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this MultiFormAttachmentDto.

        The url to the remote content of the attachment.  # noqa: E501

        :param url: The url of this MultiFormAttachmentDto.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def content(self):
        """Gets the content of this MultiFormAttachmentDto.  # noqa: E501

        The content of the attachment.  # noqa: E501

        :return: The content of this MultiFormAttachmentDto.  # noqa: E501
        :rtype: file
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this MultiFormAttachmentDto.

        The content of the attachment.  # noqa: E501

        :param content: The content of this MultiFormAttachmentDto.  # noqa: E501
        :type: file
        """

        self._content = content

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MultiFormAttachmentDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MultiFormAttachmentDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class ProblemDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message': 'str',
        'line': 'int',
        'column': 'int',
        'main_element_id': 'str',
        'element_ids': 'list[str]'
    }

    attribute_map = {
        'message': 'message',
        'line': 'line',
        'column': 'column',
        'main_element_id': 'mainElementId',
        'element_ids': 'elementIds'
    }

    def __init__(self, message=None, line=None, column=None, main_element_id=None, element_ids=None, local_vars_configuration=None):  # noqa: E501
        """ProblemDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._message = None
        self._line = None
        self._column = None
        self._main_element_id = None
        self._element_ids = None
        self.discriminator = None

        if message is not None:
            self.message = message
        self.line = line
        self.column = column
        if main_element_id is not None:
            self.main_element_id = main_element_id
        if element_ids is not None:
            self.element_ids = element_ids

    @property
    def message(self):
        """Gets the message of this ProblemDto.  # noqa: E501

        The message of the problem.  # noqa: E501

        :return: The message of this ProblemDto.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ProblemDto.

        The message of the problem.  # noqa: E501

        :param message: The message of this ProblemDto.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def line(self):
        """Gets the line of this ProblemDto.  # noqa: E501

        The line where the problem occurred.  # noqa: E501

        :return: The line of this ProblemDto.  # noqa: E501
        :rtype: int
        """
        return self._line

    @line.setter
    def line(self, line):
        """Sets the line of this ProblemDto.

        The line where the problem occurred.  # noqa: E501

        :param line: The line of this ProblemDto.  # noqa: E501
        :type: int
        """

        self._line = line

    @property
    def column(self):
        """Gets the column of this ProblemDto.  # noqa: E501

        The column where the problem occurred.  # noqa: E501

        :return: The column of this ProblemDto.  # noqa: E501
        :rtype: int
        """
        return self._column

    @column.setter
    def column(self, column):
        """Sets the column of this ProblemDto.

        The column where the problem occurred.  # noqa: E501

        :param column: The column of this ProblemDto.  # noqa: E501
        :type: int
        """

        self._column = column

    @property
    def main_element_id(self):
        """Gets the main_element_id of this ProblemDto.  # noqa: E501

        The main element id where the problem occurred.  # noqa: E501

        :return: The main_element_id of this ProblemDto.  # noqa: E501
        :rtype: str
        """
        return self._main_element_id

    @main_element_id.setter
    def main_element_id(self, main_element_id):
        """Sets the main_element_id of this ProblemDto.

        The main element id where the problem occurred.  # noqa: E501

        :param main_element_id: The main_element_id of this ProblemDto.  # noqa: E501
        :type: str
        """

        self._main_element_id = main_element_id

    @property
    def element_ids(self):
        """Gets the element_ids of this ProblemDto.  # noqa: E501

        A list of element id affected by the problem.  # noqa: E501

        :return: The element_ids of this ProblemDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._element_ids

    @element_ids.setter
    def element_ids(self, element_ids):
        """Sets the element_ids of this ProblemDto.

        A list of element id affected by the problem.  # noqa: E501

        :param element_ids: The element_ids of this ProblemDto.  # noqa: E501
        :type: list[str]
        """

        self._element_ids = element_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProblemDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProblemDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class ActivityInstanceDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'parent_activity_instance_id': 'str',
        'activity_id': 'str',
        'activity_name': 'str',
        'activity_type': 'str',
        'process_instance_id': 'str',
        'process_definition_id': 'str',
        'child_activity_instances': 'list[ActivityInstanceDto]',
        'child_transition_instances': 'list[TransitionInstanceDto]',
        'execution_ids': 'list[str]',
        'incident_ids': 'list[str]',
        'incidents': 'list[ActivityInstanceIncidentDto]'
    }

    attribute_map = {
        'id': 'id',
        'parent_activity_instance_id': 'parentActivityInstanceId',
        'activity_id': 'activityId',
        'activity_name': 'activityName',
        'activity_type': 'activityType',
        'process_instance_id': 'processInstanceId',
        'process_definition_id': 'processDefinitionId',
        'child_activity_instances': 'childActivityInstances',
        'child_transition_instances': 'childTransitionInstances',
        'execution_ids': 'executionIds',
        'incident_ids': 'incidentIds',
        'incidents': 'incidents'
    }

    def __init__(self, id=None, parent_activity_instance_id=None, activity_id=None, activity_name=None, activity_type=None, process_instance_id=None, process_definition_id=None, child_activity_instances=None, child_transition_instances=None, execution_ids=None, incident_ids=None, incidents=None, local_vars_configuration=None):  # noqa: E501
        """ActivityInstanceDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._parent_activity_instance_id = None
        self._activity_id = None
        self._activity_name = None
        self._activity_type = None
        self._process_instance_id = None
        self._process_definition_id = None
        self._child_activity_instances = None
        self._child_transition_instances = None
        self._execution_ids = None
        self._incident_ids = None
        self._incidents = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if parent_activity_instance_id is not None:
            self.parent_activity_instance_id = parent_activity_instance_id
        if activity_id is not None:
            self.activity_id = activity_id
        if activity_name is not None:
            self.activity_name = activity_name
        if activity_type is not None:
            self.activity_type = activity_type
        if process_instance_id is not None:
            self.process_instance_id = process_instance_id
        if process_definition_id is not None:
            self.process_definition_id = process_definition_id
        if child_activity_instances is not None:
            self.child_activity_instances = child_activity_instances
        if child_transition_instances is not None:
            self.child_transition_instances = child_transition_instances
        if execution_ids is not None:
            self.execution_ids = execution_ids
        if incident_ids is not None:
            self.incident_ids = incident_ids
        if incidents is not None:
            self.incidents = incidents

    @property
    def id(self):
        """Gets the id of this ActivityInstanceDto.  # noqa: E501

        The id of the activity instance.  # noqa: E501

        :return: The id of this ActivityInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ActivityInstanceDto.

        The id of the activity instance.  # noqa: E501

        :param id: The id of this ActivityInstanceDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def parent_activity_instance_id(self):
        """Gets the parent_activity_instance_id of this ActivityInstanceDto.  # noqa: E501

        The id of the parent activity instance, for example a sub process instance.  # noqa: E501

        :return: The parent_activity_instance_id of this ActivityInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._parent_activity_instance_id

    @parent_activity_instance_id.setter
    def parent_activity_instance_id(self, parent_activity_instance_id):
        """Sets the parent_activity_instance_id of this ActivityInstanceDto.

        The id of the parent activity instance, for example a sub process instance.  # noqa: E501

        :param parent_activity_instance_id: The parent_activity_instance_id of this ActivityInstanceDto.  # noqa: E501
        :type: str
        """

        self._parent_activity_instance_id = parent_activity_instance_id

    @property
    def activity_id(self):
        """Gets the activity_id of this ActivityInstanceDto.  # noqa: E501

        The id of the activity.  # noqa: E501

        :return: The activity_id of this ActivityInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_id

    @activity_id.setter
    def activity_id(self, activity_id):
        """Sets the activity_id of this ActivityInstanceDto.

        The id of the activity.  # noqa: E501

        :param activity_id: The activity_id of this ActivityInstanceDto.  # noqa: E501
        :type: str
        """

        self._activity_id = activity_id

    @property
    def activity_name(self):
        """Gets the activity_name of this ActivityInstanceDto.  # noqa: E501

        The name of the activity  # noqa: E501

        :return: The activity_name of this ActivityInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_name

    @activity_name.setter
    def activity_name(self, activity_name):
        """Sets the activity_name of this ActivityInstanceDto.

        The name of the activity  # noqa: E501

        :param activity_name: The activity_name of this ActivityInstanceDto.  # noqa: E501
        :type: str
        """

        self._activity_name = activity_name

    @property
    def activity_type(self):
        """Gets the activity_type of this ActivityInstanceDto.  # noqa: E501

        The type of activity (corresponds to the XML element name in the BPMN 2.0, e.g., 'userTask')  # noqa: E501

        :return: The activity_type of this ActivityInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_type

    @activity_type.setter
    def activity_type(self, activity_type):
        """Sets the activity_type of this ActivityInstanceDto.

        The type of activity (corresponds to the XML element name in the BPMN 2.0, e.g., 'userTask')  # noqa: E501

        :param activity_type: The activity_type of this ActivityInstanceDto.  # noqa: E501
        :type: str
        """

        self._activity_type = activity_type

    @property
    def process_instance_id(self):
        """Gets the process_instance_id of this ActivityInstanceDto.  # noqa: E501

        The id of the process instance this activity instance is part of.  # noqa: E501

        :return: The process_instance_id of this ActivityInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._process_instance_id

    @process_instance_id.setter
    def process_instance_id(self, process_instance_id):
        """Sets the process_instance_id of this ActivityInstanceDto.

        The id of the process instance this activity instance is part of.  # noqa: E501

        :param process_instance_id: The process_instance_id of this ActivityInstanceDto.  # noqa: E501
        :type: str
        """

        self._process_instance_id = process_instance_id

    @property
    def process_definition_id(self):
        """Gets the process_definition_id of this ActivityInstanceDto.  # noqa: E501

        The id of the process definition.  # noqa: E501

        :return: The process_definition_id of this ActivityInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_id

    @process_definition_id.setter
    def process_definition_id(self, process_definition_id):
        """Sets the process_definition_id of this ActivityInstanceDto.

        The id of the process definition.  # noqa: E501

        :param process_definition_id: The process_definition_id of this ActivityInstanceDto.  # noqa: E501
        :type: str
        """

        self._process_definition_id = process_definition_id

    @property
    def child_activity_instances(self):
        """Gets the child_activity_instances of this ActivityInstanceDto.  # noqa: E501

        A list of child activity instances.  # noqa: E501

        :return: The child_activity_instances of this ActivityInstanceDto.  # noqa: E501
        :rtype: list[ActivityInstanceDto]
        """
        return self._child_activity_instances

    @child_activity_instances.setter
    def child_activity_instances(self, child_activity_instances):
        """Sets the child_activity_instances of this ActivityInstanceDto.

        A list of child activity instances.  # noqa: E501

        :param child_activity_instances: The child_activity_instances of this ActivityInstanceDto.  # noqa: E501
        :type: list[ActivityInstanceDto]
        """

        self._child_activity_instances = child_activity_instances

    @property
    def child_transition_instances(self):
        """Gets the child_transition_instances of this ActivityInstanceDto.  # noqa: E501

        A list of child transition instances. A transition instance represents an execution waiting in an asynchronous continuation.  # noqa: E501

        :return: The child_transition_instances of this ActivityInstanceDto.  # noqa: E501
        :rtype: list[TransitionInstanceDto]
        """
        return self._child_transition_instances

    @child_transition_instances.setter
    def child_transition_instances(self, child_transition_instances):
        """Sets the child_transition_instances of this ActivityInstanceDto.

        A list of child transition instances. A transition instance represents an execution waiting in an asynchronous continuation.  # noqa: E501

        :param child_transition_instances: The child_transition_instances of this ActivityInstanceDto.  # noqa: E501
        :type: list[TransitionInstanceDto]
        """

        self._child_transition_instances = child_transition_instances

    @property
    def execution_ids(self):
        """Gets the execution_ids of this ActivityInstanceDto.  # noqa: E501

        A list of execution ids.  # noqa: E501

        :return: The execution_ids of this ActivityInstanceDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._execution_ids

    @execution_ids.setter
    def execution_ids(self, execution_ids):
        """Sets the execution_ids of this ActivityInstanceDto.

        A list of execution ids.  # noqa: E501

        :param execution_ids: The execution_ids of this ActivityInstanceDto.  # noqa: E501
        :type: list[str]
        """

        self._execution_ids = execution_ids

    @property
    def incident_ids(self):
        """Gets the incident_ids of this ActivityInstanceDto.  # noqa: E501

        A list of incident ids.  # noqa: E501

        :return: The incident_ids of this ActivityInstanceDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._incident_ids

    @incident_ids.setter
    def incident_ids(self, incident_ids):
        """Sets the incident_ids of this ActivityInstanceDto.

        A list of incident ids.  # noqa: E501

        :param incident_ids: The incident_ids of this ActivityInstanceDto.  # noqa: E501
        :type: list[str]
        """

        self._incident_ids = incident_ids

    @property
    def incidents(self):
        """Gets the incidents of this ActivityInstanceDto.  # noqa: E501

        A list of JSON objects containing incident specific properties: * `id`: the id of the incident * `activityId`: the activity id in which the incident occurred  # noqa: E501

        :return: The incidents of this ActivityInstanceDto.  # noqa: E501
        :rtype: list[ActivityInstanceIncidentDto]
        """
        return self._incidents

    @incidents.setter
    def incidents(self, incidents):
        """Sets the incidents of this ActivityInstanceDto.

        A list of JSON objects containing incident specific properties: * `id`: the id of the incident * `activityId`: the activity id in which the incident occurred  # noqa: E501

        :param incidents: The incidents of this ActivityInstanceDto.  # noqa: E501
        :type: list[ActivityInstanceIncidentDto]
        """

        self._incidents = incidents

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityInstanceDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ActivityInstanceDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class RestartProcessInstanceDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'process_instance_ids': 'list[str]',
        'historic_process_instance_query': 'HistoricProcessInstanceQueryDto',
        'skip_custom_listeners': 'bool',
        'skip_io_mappings': 'bool',
        'initial_variables': 'bool',
        'without_business_key': 'bool',
        'instructions': 'list[RestartProcessInstanceModificationInstructionDto]'
    }

    attribute_map = {
        'process_instance_ids': 'processInstanceIds',
        'historic_process_instance_query': 'historicProcessInstanceQuery',
        'skip_custom_listeners': 'skipCustomListeners',
        'skip_io_mappings': 'skipIoMappings',
        'initial_variables': 'initialVariables',
        'without_business_key': 'withoutBusinessKey',
        'instructions': 'instructions'
    }

    def __init__(self, process_instance_ids=None, historic_process_instance_query=None, skip_custom_listeners=None, skip_io_mappings=None, initial_variables=None, without_business_key=None, instructions=None, local_vars_configuration=None):  # noqa: E501
        """RestartProcessInstanceDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._process_instance_ids = None
        self._historic_process_instance_query = None
        self._skip_custom_listeners = None
        self._skip_io_mappings = None
        self._initial_variables = None
        self._without_business_key = None
        self._instructions = None
        self.discriminator = None

        if process_instance_ids is not None:
            self.process_instance_ids = process_instance_ids
        if historic_process_instance_query is not None:
            self.historic_process_instance_query = historic_process_instance_query
        self.skip_custom_listeners = skip_custom_listeners
        self.skip_io_mappings = skip_io_mappings
        self.initial_variables = initial_variables
        self.without_business_key = without_business_key
        if instructions is not None:
            self.instructions = instructions

    @property
    def process_instance_ids(self):
        """Gets the process_instance_ids of this RestartProcessInstanceDto.  # noqa: E501

        A list of process instance ids to restart.  # noqa: E501

        :return: The process_instance_ids of this RestartProcessInstanceDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._process_instance_ids

    @process_instance_ids.setter
    def process_instance_ids(self, process_instance_ids):
        """Sets the process_instance_ids of this RestartProcessInstanceDto.

        A list of process instance ids to restart.  # noqa: E501

        :param process_instance_ids: The process_instance_ids of this RestartProcessInstanceDto.  # noqa: E501
        :type: list[str]
        """

        self._process_instance_ids = process_instance_ids

    @property
    def historic_process_instance_query(self):
        """Gets the historic_process_instance_query of this RestartProcessInstanceDto.  # noqa: E501


        :return: The historic_process_instance_query of this RestartProcessInstanceDto.  # noqa: E501
        :rtype: HistoricProcessInstanceQueryDto
        """
        return self._historic_process_instance_query

    @historic_process_instance_query.setter
    def historic_process_instance_query(self, historic_process_instance_query):
        """Sets the historic_process_instance_query of this RestartProcessInstanceDto.


        :param historic_process_instance_query: The historic_process_instance_query of this RestartProcessInstanceDto.  # noqa: E501
        :type: HistoricProcessInstanceQueryDto
        """

        self._historic_process_instance_query = historic_process_instance_query

    @property
    def skip_custom_listeners(self):
        """Gets the skip_custom_listeners of this RestartProcessInstanceDto.  # noqa: E501

        Skip execution listener invocation for activities that are started as part of this request.  # noqa: E501

        :return: The skip_custom_listeners of this RestartProcessInstanceDto.  # noqa: E501
        :rtype: bool
        """
        return self._skip_custom_listeners

    @skip_custom_listeners.setter
    def skip_custom_listeners(self, skip_custom_listeners):
        """Sets the skip_custom_listeners of this RestartProcessInstanceDto.

        Skip execution listener invocation for activities that are started as part of this request.  # noqa: E501

        :param skip_custom_listeners: The skip_custom_listeners of this RestartProcessInstanceDto.  # noqa: E501
        :type: bool
        """

        self._skip_custom_listeners = skip_custom_listeners

    @property
    def skip_io_mappings(self):
        """Gets the skip_io_mappings of this RestartProcessInstanceDto.  # noqa: E501

        Skip execution of [input/output variable mappings](https://docs.camunda.org/manual/7.14/user-guide/process-engine/variables/#input-output-variable-mapping) for activities that are started as part of this request.  # noqa: E501

        :return: The skip_io_mappings of this RestartProcessInstanceDto.  # noqa: E501
        :rtype: bool
        """
        return self._skip_io_mappings

    @skip_io_mappings.setter
    def skip_io_mappings(self, skip_io_mappings):
        """Sets the skip_io_mappings of this RestartProcessInstanceDto.

        Skip execution of [input/output variable mappings](https://docs.camunda.org/manual/7.14/user-guide/process-engine/variables/#input-output-variable-mapping) for activities that are started as part of this request.  # noqa: E501

        :param skip_io_mappings: The skip_io_mappings of this RestartProcessInstanceDto.  # noqa: E501
        :type: bool
        """

        self._skip_io_mappings = skip_io_mappings

    @property
    def initial_variables(self):
        """Gets the initial_variables of this RestartProcessInstanceDto.  # noqa: E501

        Set the initial set of variables during restart. By default, the last set of variables is used.  # noqa: E501

        :return: The initial_variables of this RestartProcessInstanceDto.  # noqa: E501
        :rtype: bool
        """
        return self._initial_variables

    @initial_variables.setter
    def initial_variables(self, initial_variables):
        """Sets the initial_variables of this RestartProcessInstanceDto.

        Set the initial set of variables during restart. By default, the last set of variables is used.  # noqa: E501

        :param initial_variables: The initial_variables of this RestartProcessInstanceDto.  # noqa: E501
        :type: bool
        """

        self._initial_variables = initial_variables

    @property
    def without_business_key(self):
        """Gets the without_business_key of this RestartProcessInstanceDto.  # noqa: E501

        Do not take over the business key of the historic process instance.  # noqa: E501

        :return: The without_business_key of this RestartProcessInstanceDto.  # noqa: E501
        :rtype: bool
        """
        return self._without_business_key

    @without_business_key.setter
    def without_business_key(self, without_business_key):
        """Sets the without_business_key of this RestartProcessInstanceDto.

        Do not take over the business key of the historic process instance.  # noqa: E501

        :param without_business_key: The without_business_key of this RestartProcessInstanceDto.  # noqa: E501
        :type: bool
        """

        self._without_business_key = without_business_key

    @property
    def instructions(self):
        """Gets the instructions of this RestartProcessInstanceDto.  # noqa: E501

        **Optional**. A JSON array of instructions that specify which activities to start the process instance at. If this property is omitted, the process instance starts at its default blank start event.  # noqa: E501

        :return: The instructions of this RestartProcessInstanceDto.  # noqa: E501
        :rtype: list[RestartProcessInstanceModificationInstructionDto]
        """
        return self._instructions

    @instructions.setter
    def instructions(self, instructions):
        """Sets the instructions of this RestartProcessInstanceDto.

        **Optional**. A JSON array of instructions that specify which activities to start the process instance at. If this property is omitted, the process instance starts at its default blank start event.  # noqa: E501

        :param instructions: The instructions of this RestartProcessInstanceDto.  # noqa: E501
        :type: list[RestartProcessInstanceModificationInstructionDto]
        """

        self._instructions = instructions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RestartProcessInstanceDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RestartProcessInstanceDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class EventSubscriptionQueryDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'event_subscription_id': 'str',
        'event_name': 'str',
        'event_type': 'str',
        'execution_id': 'str',
        'process_instance_id': 'str',
        'activity_id': 'str',
        'tenant_id_in': 'list[str]',
        'without_tenant_id': 'bool',
        'include_event_subscriptions_without_tenant_id': 'bool',
        'sorting': 'list[EventSubscriptionQueryDtoSorting]'
    }

    attribute_map = {
        'event_subscription_id': 'eventSubscriptionId',
        'event_name': 'eventName',
        'event_type': 'eventType',
        'execution_id': 'executionId',
        'process_instance_id': 'processInstanceId',
        'activity_id': 'activityId',
        'tenant_id_in': 'tenantIdIn',
        'without_tenant_id': 'withoutTenantId',
        'include_event_subscriptions_without_tenant_id': 'includeEventSubscriptionsWithoutTenantId',
        'sorting': 'sorting'
    }

    def __init__(self, event_subscription_id=None, event_name=None, event_type=None, execution_id=None, process_instance_id=None, activity_id=None, tenant_id_in=None, without_tenant_id=None, include_event_subscriptions_without_tenant_id=None, sorting=None, local_vars_configuration=None):  # noqa: E501
        """EventSubscriptionQueryDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._event_subscription_id = None
        self._event_name = None
        self._event_type = None
        self._execution_id = None
        self._process_instance_id = None
        self._activity_id = None
        self._tenant_id_in = None
        self._without_tenant_id = None
        self._include_event_subscriptions_without_tenant_id = None
        self._sorting = None
        self.discriminator = None

        if event_subscription_id is not None:
            self.event_subscription_id = event_subscription_id
        if event_name is not None:
            self.event_name = event_name
        if event_type is not None:
            self.event_type = event_type
        if execution_id is not None:
            self.execution_id = execution_id
        if process_instance_id is not None:
            self.process_instance_id = process_instance_id
        if activity_id is not None:
            self.activity_id = activity_id
        if tenant_id_in is not None:
            self.tenant_id_in = tenant_id_in
        self.without_tenant_id = without_tenant_id
        self.include_event_subscriptions_without_tenant_id = include_event_subscriptions_without_tenant_id
        if sorting is not None:
            self.sorting = sorting

    @property
    def event_subscription_id(self):
        """Gets the event_subscription_id of this EventSubscriptionQueryDto.  # noqa: E501

        The id of the event subscription.  # noqa: E501

        :return: The event_subscription_id of this EventSubscriptionQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._event_subscription_id

    @event_subscription_id.setter
    def event_subscription_id(self, event_subscription_id):
        """Sets the event_subscription_id of this EventSubscriptionQueryDto.

        The id of the event subscription.  # noqa: E501

        :param event_subscription_id: The event_subscription_id of this EventSubscriptionQueryDto.  # noqa: E501
        :type: str
        """

        self._event_subscription_id = event_subscription_id

    @property
    def event_name(self):
        """Gets the event_name of this EventSubscriptionQueryDto.  # noqa: E501

        The name of the event this subscription belongs to as defined in the process model.  # noqa: E501

        :return: The event_name of this EventSubscriptionQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this EventSubscriptionQueryDto.

        The name of the event this subscription belongs to as defined in the process model.  # noqa: E501

        :param event_name: The event_name of this EventSubscriptionQueryDto.  # noqa: E501
        :type: str
        """

        self._event_name = event_name

    @property
    def event_type(self):
        """Gets the event_type of this EventSubscriptionQueryDto.  # noqa: E501

        The type of the event subscription.  # noqa: E501

        :return: The event_type of this EventSubscriptionQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this EventSubscriptionQueryDto.

        The type of the event subscription.  # noqa: E501

        :param event_type: The event_type of this EventSubscriptionQueryDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["message", "signal", "compensate", "conditional"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_type` ({0}), must be one of {1}"  # noqa: E501
                .format(event_type, allowed_values)
            )

        self._event_type = event_type

    @property
    def execution_id(self):
        """Gets the execution_id of this EventSubscriptionQueryDto.  # noqa: E501

        The execution that is subscribed on the referenced event.  # noqa: E501

        :return: The execution_id of this EventSubscriptionQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this EventSubscriptionQueryDto.

        The execution that is subscribed on the referenced event.  # noqa: E501

        :param execution_id: The execution_id of this EventSubscriptionQueryDto.  # noqa: E501
        :type: str
        """

        self._execution_id = execution_id

    @property
    def process_instance_id(self):
        """Gets the process_instance_id of this EventSubscriptionQueryDto.  # noqa: E501

        The process instance this subscription belongs to.  # noqa: E501

        :return: The process_instance_id of this EventSubscriptionQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._process_instance_id

    @process_instance_id.setter
    def process_instance_id(self, process_instance_id):
        """Sets the process_instance_id of this EventSubscriptionQueryDto.

        The process instance this subscription belongs to.  # noqa: E501

        :param process_instance_id: The process_instance_id of this EventSubscriptionQueryDto.  # noqa: E501
        :type: str
        """

        self._process_instance_id = process_instance_id

    @property
    def activity_id(self):
        """Gets the activity_id of this EventSubscriptionQueryDto.  # noqa: E501

        The identifier of the activity that this event subscription belongs to. This could for example be the id of a receive task.  # noqa: E501

        :return: The activity_id of this EventSubscriptionQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_id

    @activity_id.setter
    def activity_id(self, activity_id):
        """Sets the activity_id of this EventSubscriptionQueryDto.

        The identifier of the activity that this event subscription belongs to. This could for example be the id of a receive task.  # noqa: E501

        :param activity_id: The activity_id of this EventSubscriptionQueryDto.  # noqa: E501
        :type: str
        """

        self._activity_id = activity_id

    @property
    def tenant_id_in(self):
        """Gets the tenant_id_in of this EventSubscriptionQueryDto.  # noqa: E501

        Filter by a comma-separated list of tenant ids. Only select subscriptions that belong to one of the given tenant ids.  # noqa: E501

        :return: The tenant_id_in of this EventSubscriptionQueryDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._tenant_id_in

    @tenant_id_in.setter
    def tenant_id_in(self, tenant_id_in):
        """Sets the tenant_id_in of this EventSubscriptionQueryDto.

        Filter by a comma-separated list of tenant ids. Only select subscriptions that belong to one of the given tenant ids.  # noqa: E501

        :param tenant_id_in: The tenant_id_in of this EventSubscriptionQueryDto.  # noqa: E501
        :type: list[str]
        """

        self._tenant_id_in = tenant_id_in

    @property
    def without_tenant_id(self):
        """Gets the without_tenant_id of this EventSubscriptionQueryDto.  # noqa: E501

        Only select subscriptions which have no tenant id. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :return: The without_tenant_id of this EventSubscriptionQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._without_tenant_id

    @without_tenant_id.setter
    def without_tenant_id(self, without_tenant_id):
        """Sets the without_tenant_id of this EventSubscriptionQueryDto.

        Only select subscriptions which have no tenant id. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :param without_tenant_id: The without_tenant_id of this EventSubscriptionQueryDto.  # noqa: E501
        :type: bool
        """

        self._without_tenant_id = without_tenant_id

    @property
    def include_event_subscriptions_without_tenant_id(self):
        """Gets the include_event_subscriptions_without_tenant_id of this EventSubscriptionQueryDto.  # noqa: E501

        Select event subscriptions which have no tenant id. Can be used in combination with tenantIdIn parameter. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :return: The include_event_subscriptions_without_tenant_id of this EventSubscriptionQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._include_event_subscriptions_without_tenant_id

    @include_event_subscriptions_without_tenant_id.setter
    def include_event_subscriptions_without_tenant_id(self, include_event_subscriptions_without_tenant_id):
        """Sets the include_event_subscriptions_without_tenant_id of this EventSubscriptionQueryDto.

        Select event subscriptions which have no tenant id. Can be used in combination with tenantIdIn parameter. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :param include_event_subscriptions_without_tenant_id: The include_event_subscriptions_without_tenant_id of this EventSubscriptionQueryDto.  # noqa: E501
        :type: bool
        """

        self._include_event_subscriptions_without_tenant_id = include_event_subscriptions_without_tenant_id

    @property
    def sorting(self):
        """Gets the sorting of this EventSubscriptionQueryDto.  # noqa: E501

        Apply sorting of the result  # noqa: E501

        :return: The sorting of this EventSubscriptionQueryDto.  # noqa: E501
        :rtype: list[EventSubscriptionQueryDtoSorting]
        """
        return self._sorting

    @sorting.setter
    def sorting(self, sorting):
        """Sets the sorting of this EventSubscriptionQueryDto.

        Apply sorting of the result  # noqa: E501

        :param sorting: The sorting of this EventSubscriptionQueryDto.  # noqa: E501
        :type: list[EventSubscriptionQueryDtoSorting]
        """

        self._sorting = sorting

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventSubscriptionQueryDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EventSubscriptionQueryDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class HistoricProcessInstanceQueryDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'process_instance_id': 'str',
        'process_instance_ids': 'list[str]',
        'process_definition_id': 'str',
        'process_definition_key': 'str',
        'process_definition_key_in': 'list[str]',
        'process_definition_name': 'str',
        'process_definition_name_like': 'str',
        'process_definition_key_not_in': 'list[str]',
        'process_instance_business_key': 'str',
        'process_instance_business_key_like': 'str',
        'root_process_instances': 'bool',
        'finished': 'bool',
        'unfinished': 'bool',
        'with_incidents': 'bool',
        'with_root_incidents': 'bool',
        'incident_type': 'str',
        'incident_status': 'str',
        'incident_message': 'str',
        'incident_message_like': 'str',
        'started_before': 'datetime',
        'started_after': 'datetime',
        'finished_before': 'datetime',
        'finished_after': 'datetime',
        'executed_activity_after': 'datetime',
        'executed_activity_before': 'datetime',
        'executed_job_after': 'datetime',
        'executed_job_before': 'datetime',
        'started_by': 'str',
        'super_process_instance_id': 'str',
        'sub_process_instance_id': 'str',
        'super_case_instance_id': 'str',
        'sub_case_instance_id': 'str',
        'case_instance_id': 'str',
        'tenant_id_in': 'list[str]',
        'without_tenant_id': 'bool',
        'executed_activity_id_in': 'list[str]',
        'active_activity_id_in': 'list[str]',
        'active': 'bool',
        'suspended': 'bool',
        'completed': 'bool',
        'externally_terminated': 'bool',
        'internally_terminated': 'bool',
        'variables': 'list[VariableQueryParameterDto]',
        'variable_names_ignore_case': 'bool',
        'variable_values_ignore_case': 'bool',
        'or_queries': 'list[HistoricProcessInstanceQueryDto]',
        'sorting': 'list[HistoricProcessInstanceQueryDtoSorting]'
    }

    attribute_map = {
        'process_instance_id': 'processInstanceId',
        'process_instance_ids': 'processInstanceIds',
        'process_definition_id': 'processDefinitionId',
        'process_definition_key': 'processDefinitionKey',
        'process_definition_key_in': 'processDefinitionKeyIn',
        'process_definition_name': 'processDefinitionName',
        'process_definition_name_like': 'processDefinitionNameLike',
        'process_definition_key_not_in': 'processDefinitionKeyNotIn',
        'process_instance_business_key': 'processInstanceBusinessKey',
        'process_instance_business_key_like': 'processInstanceBusinessKeyLike',
        'root_process_instances': 'rootProcessInstances',
        'finished': 'finished',
        'unfinished': 'unfinished',
        'with_incidents': 'withIncidents',
        'with_root_incidents': 'withRootIncidents',
        'incident_type': 'incidentType',
        'incident_status': 'incidentStatus',
        'incident_message': 'incidentMessage',
        'incident_message_like': 'incidentMessageLike',
        'started_before': 'startedBefore',
        'started_after': 'startedAfter',
        'finished_before': 'finishedBefore',
        'finished_after': 'finishedAfter',
        'executed_activity_after': 'executedActivityAfter',
        'executed_activity_before': 'executedActivityBefore',
        'executed_job_after': 'executedJobAfter',
        'executed_job_before': 'executedJobBefore',
        'started_by': 'startedBy',
        'super_process_instance_id': 'superProcessInstanceId',
        'sub_process_instance_id': 'subProcessInstanceId',
        'super_case_instance_id': 'superCaseInstanceId',
        'sub_case_instance_id': 'subCaseInstanceId',
        'case_instance_id': 'caseInstanceId',
        'tenant_id_in': 'tenantIdIn',
        'without_tenant_id': 'withoutTenantId',
        'executed_activity_id_in': 'executedActivityIdIn',
        'active_activity_id_in': 'activeActivityIdIn',
        'active': 'active',
        'suspended': 'suspended',
        'completed': 'completed',
        'externally_terminated': 'externallyTerminated',
        'internally_terminated': 'internallyTerminated',
        'variables': 'variables',
        'variable_names_ignore_case': 'variableNamesIgnoreCase',
        'variable_values_ignore_case': 'variableValuesIgnoreCase',
        'or_queries': 'orQueries',
        'sorting': 'sorting'
    }

    def __init__(self, process_instance_id=None, process_instance_ids=None, process_definition_id=None, process_definition_key=None, process_definition_key_in=None, process_definition_name=None, process_definition_name_like=None, process_definition_key_not_in=None, process_instance_business_key=None, process_instance_business_key_like=None, root_process_instances=None, finished=None, unfinished=None, with_incidents=None, with_root_incidents=None, incident_type=None, incident_status=None, incident_message=None, incident_message_like=None, started_before=None, started_after=None, finished_before=None, finished_after=None, executed_activity_after=None, executed_activity_before=None, executed_job_after=None, executed_job_before=None, started_by=None, super_process_instance_id=None, sub_process_instance_id=None, super_case_instance_id=None, sub_case_instance_id=None, case_instance_id=None, tenant_id_in=None, without_tenant_id=None, executed_activity_id_in=None, active_activity_id_in=None, active=None, suspended=None, completed=None, externally_terminated=None, internally_terminated=None, variables=None, variable_names_ignore_case=None, variable_values_ignore_case=None, or_queries=None, sorting=None, local_vars_configuration=None):  # noqa: E501
        """HistoricProcessInstanceQueryDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._process_instance_id = None
        self._process_instance_ids = None
        self._process_definition_id = None
        self._process_definition_key = None
        self._process_definition_key_in = None
        self._process_definition_name = None
        self._process_definition_name_like = None
        self._process_definition_key_not_in = None
        self._process_instance_business_key = None
        self._process_instance_business_key_like = None
        self._root_process_instances = None
        self._finished = None
        self._unfinished = None
        self._with_incidents = None
        self._with_root_incidents = None
        self._incident_type = None
        self._incident_status = None
        self._incident_message = None
        self._incident_message_like = None
        self._started_before = None
        self._started_after = None
        self._finished_before = None
        self._finished_after = None
        self._executed_activity_after = None
        self._executed_activity_before = None
        self._executed_job_after = None
        self._executed_job_before = None
        self._started_by = None
        self._super_process_instance_id = None
        self._sub_process_instance_id = None
        self._super_case_instance_id = None
        self._sub_case_instance_id = None
        self._case_instance_id = None
        self._tenant_id_in = None
        self._without_tenant_id = None
        self._executed_activity_id_in = None
        self._active_activity_id_in = None
        self._active = None
        self._suspended = None
        self._completed = None
        self._externally_terminated = None
        self._internally_terminated = None
        self._variables = None
        self._variable_names_ignore_case = None
        self._variable_values_ignore_case = None
        self._or_queries = None
        self._sorting = None
        self.discriminator = None

        if process_instance_id is not None:
            self.process_instance_id = process_instance_id
        if process_instance_ids is not None:
            self.process_instance_ids = process_instance_ids
        if process_definition_id is not None:
            self.process_definition_id = process_definition_id
        if process_definition_key is not None:
            self.process_definition_key = process_definition_key
        if process_definition_key_in is not None:
            self.process_definition_key_in = process_definition_key_in
        if process_definition_name is not None:
            self.process_definition_name = process_definition_name
        if process_definition_name_like is not None:
            self.process_definition_name_like = process_definition_name_like
        if process_definition_key_not_in is not None:
            self.process_definition_key_not_in = process_definition_key_not_in
        if process_instance_business_key is not None:
            self.process_instance_business_key = process_instance_business_key
        if process_instance_business_key_like is not None:
            self.process_instance_business_key_like = process_instance_business_key_like
        self.root_process_instances = root_process_instances
        self.finished = finished
        self.unfinished = unfinished
        self.with_incidents = with_incidents
        self.with_root_incidents = with_root_incidents
        if incident_type is not None:
            self.incident_type = incident_type
        if incident_status is not None:
            self.incident_status = incident_status
        if incident_message is not None:
            self.incident_message = incident_message
        if incident_message_like is not None:
            self.incident_message_like = incident_message_like
        self.started_before = started_before
        self.started_after = started_after
        self.finished_before = finished_before
        self.finished_after = finished_after
        self.executed_activity_after = executed_activity_after
        self.executed_activity_before = executed_activity_before
        self.executed_job_after = executed_job_after
        self.executed_job_before = executed_job_before
        if started_by is not None:
            self.started_by = started_by
        if super_process_instance_id is not None:
            self.super_process_instance_id = super_process_instance_id
        if sub_process_instance_id is not None:
            self.sub_process_instance_id = sub_process_instance_id
        if super_case_instance_id is not None:
            self.super_case_instance_id = super_case_instance_id
        if sub_case_instance_id is not None:
            self.sub_case_instance_id = sub_case_instance_id
        if case_instance_id is not None:
            self.case_instance_id = case_instance_id
        if tenant_id_in is not None:
            self.tenant_id_in = tenant_id_in
        self.without_tenant_id = without_tenant_id
        if executed_activity_id_in is not None:
            self.executed_activity_id_in = executed_activity_id_in
        if active_activity_id_in is not None:
            self.active_activity_id_in = active_activity_id_in
        self.active = active
        self.suspended = suspended
        self.completed = completed
        self.externally_terminated = externally_terminated
        self.internally_terminated = internally_terminated
        if variables is not None:
            self.variables = variables
        self.variable_names_ignore_case = variable_names_ignore_case
        self.variable_values_ignore_case = variable_values_ignore_case
        if or_queries is not None:
            self.or_queries = or_queries
        if sorting is not None:
            self.sorting = sorting

    @property
    def process_instance_id(self):
        """Gets the process_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by process instance id.  # noqa: E501

        :return: The process_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._process_instance_id

    @process_instance_id.setter
    def process_instance_id(self, process_instance_id):
        """Sets the process_instance_id of this HistoricProcessInstanceQueryDto.

        Filter by process instance id.  # noqa: E501

        :param process_instance_id: The process_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._process_instance_id = process_instance_id

    @property
    def process_instance_ids(self):
        """Gets the process_instance_ids of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by process instance ids. Must be a JSON array of `Strings`.  # noqa: E501

        :return: The process_instance_ids of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._process_instance_ids

    @process_instance_ids.setter
    def process_instance_ids(self, process_instance_ids):
        """Sets the process_instance_ids of this HistoricProcessInstanceQueryDto.

        Filter by process instance ids. Must be a JSON array of `Strings`.  # noqa: E501

        :param process_instance_ids: The process_instance_ids of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: list[str]
        """

        self._process_instance_ids = process_instance_ids

    @property
    def process_definition_id(self):
        """Gets the process_definition_id of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by the process definition the instances run on.  # noqa: E501

        :return: The process_definition_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_id

    @process_definition_id.setter
    def process_definition_id(self, process_definition_id):
        """Sets the process_definition_id of this HistoricProcessInstanceQueryDto.

        Filter by the process definition the instances run on.  # noqa: E501

        :param process_definition_id: The process_definition_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._process_definition_id = process_definition_id

    @property
    def process_definition_key(self):
        """Gets the process_definition_key of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by the key of the process definition the instances run on.  # noqa: E501

        :return: The process_definition_key of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_key

    @process_definition_key.setter
    def process_definition_key(self, process_definition_key):
        """Sets the process_definition_key of this HistoricProcessInstanceQueryDto.

        Filter by the key of the process definition the instances run on.  # noqa: E501

        :param process_definition_key: The process_definition_key of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._process_definition_key = process_definition_key

    @property
    def process_definition_key_in(self):
        """Gets the process_definition_key_in of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by a list of process definition keys. A process instance must have one of the given process definition keys. Must be a JSON array of `Strings`.  # noqa: E501

        :return: The process_definition_key_in of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._process_definition_key_in

    @process_definition_key_in.setter
    def process_definition_key_in(self, process_definition_key_in):
        """Sets the process_definition_key_in of this HistoricProcessInstanceQueryDto.

        Filter by a list of process definition keys. A process instance must have one of the given process definition keys. Must be a JSON array of `Strings`.  # noqa: E501

        :param process_definition_key_in: The process_definition_key_in of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: list[str]
        """

        self._process_definition_key_in = process_definition_key_in

    @property
    def process_definition_name(self):
        """Gets the process_definition_name of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by the name of the process definition the instances run on.  # noqa: E501

        :return: The process_definition_name of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_name

    @process_definition_name.setter
    def process_definition_name(self, process_definition_name):
        """Sets the process_definition_name of this HistoricProcessInstanceQueryDto.

        Filter by the name of the process definition the instances run on.  # noqa: E501

        :param process_definition_name: The process_definition_name of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._process_definition_name = process_definition_name

    @property
    def process_definition_name_like(self):
        """Gets the process_definition_name_like of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by process definition names that the parameter is a substring of.  # noqa: E501

        :return: The process_definition_name_like of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_name_like

    @process_definition_name_like.setter
    def process_definition_name_like(self, process_definition_name_like):
        """Sets the process_definition_name_like of this HistoricProcessInstanceQueryDto.

        Filter by process definition names that the parameter is a substring of.  # noqa: E501

        :param process_definition_name_like: The process_definition_name_like of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._process_definition_name_like = process_definition_name_like

    @property
    def process_definition_key_not_in(self):
        """Gets the process_definition_key_not_in of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Exclude instances that belong to a set of process definitions. Must be a JSON array of `Strings`.  # noqa: E501

        :return: The process_definition_key_not_in of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._process_definition_key_not_in

    @process_definition_key_not_in.setter
    def process_definition_key_not_in(self, process_definition_key_not_in):
        """Sets the process_definition_key_not_in of this HistoricProcessInstanceQueryDto.

        Exclude instances that belong to a set of process definitions. Must be a JSON array of `Strings`.  # noqa: E501

        :param process_definition_key_not_in: The process_definition_key_not_in of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: list[str]
        """

        self._process_definition_key_not_in = process_definition_key_not_in

    @property
    def process_instance_business_key(self):
        """Gets the process_instance_business_key of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by process instance business key.  # noqa: E501

        :return: The process_instance_business_key of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._process_instance_business_key

    @process_instance_business_key.setter
    def process_instance_business_key(self, process_instance_business_key):
        """Sets the process_instance_business_key of this HistoricProcessInstanceQueryDto.

        Filter by process instance business key.  # noqa: E501

        :param process_instance_business_key: The process_instance_business_key of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._process_instance_business_key = process_instance_business_key

    @property
    def process_instance_business_key_like(self):
        """Gets the process_instance_business_key_like of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by process instance business key that the parameter is a substring of.  # noqa: E501

        :return: The process_instance_business_key_like of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._process_instance_business_key_like

    @process_instance_business_key_like.setter
    def process_instance_business_key_like(self, process_instance_business_key_like):
        """Sets the process_instance_business_key_like of this HistoricProcessInstanceQueryDto.

        Filter by process instance business key that the parameter is a substring of.  # noqa: E501

        :param process_instance_business_key_like: The process_instance_business_key_like of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._process_instance_business_key_like = process_instance_business_key_like

    @property
    def root_process_instances(self):
        """Gets the root_process_instances of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict the query to all process instances that are top level process instances.  # noqa: E501

        :return: The root_process_instances of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._root_process_instances

    @root_process_instances.setter
    def root_process_instances(self, root_process_instances):
        """Sets the root_process_instances of this HistoricProcessInstanceQueryDto.

        Restrict the query to all process instances that are top level process instances.  # noqa: E501

        :param root_process_instances: The root_process_instances of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._root_process_instances = root_process_instances

    @property
    def finished(self):
        """Gets the finished of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Only include finished process instances. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :return: The finished of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._finished

    @finished.setter
    def finished(self, finished):
        """Sets the finished of this HistoricProcessInstanceQueryDto.

        Only include finished process instances. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :param finished: The finished of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._finished = finished

    @property
    def unfinished(self):
        """Gets the unfinished of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Only include unfinished process instances. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :return: The unfinished of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._unfinished

    @unfinished.setter
    def unfinished(self, unfinished):
        """Sets the unfinished of this HistoricProcessInstanceQueryDto.

        Only include unfinished process instances. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :param unfinished: The unfinished of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._unfinished = unfinished

    @property
    def with_incidents(self):
        """Gets the with_incidents of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Only include process instances which have an incident. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :return: The with_incidents of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._with_incidents

    @with_incidents.setter
    def with_incidents(self, with_incidents):
        """Sets the with_incidents of this HistoricProcessInstanceQueryDto.

        Only include process instances which have an incident. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :param with_incidents: The with_incidents of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._with_incidents = with_incidents

    @property
    def with_root_incidents(self):
        """Gets the with_root_incidents of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Only include process instances which have a root incident. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :return: The with_root_incidents of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._with_root_incidents

    @with_root_incidents.setter
    def with_root_incidents(self, with_root_incidents):
        """Sets the with_root_incidents of this HistoricProcessInstanceQueryDto.

        Only include process instances which have a root incident. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :param with_root_incidents: The with_root_incidents of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._with_root_incidents = with_root_incidents

    @property
    def incident_type(self):
        """Gets the incident_type of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by the incident type. See the [User Guide](https://docs.camunda.org/manual/7.14/user-guide/process-engine/incidents/#incident-types) for a list of incident types.  # noqa: E501

        :return: The incident_type of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._incident_type

    @incident_type.setter
    def incident_type(self, incident_type):
        """Sets the incident_type of this HistoricProcessInstanceQueryDto.

        Filter by the incident type. See the [User Guide](https://docs.camunda.org/manual/7.14/user-guide/process-engine/incidents/#incident-types) for a list of incident types.  # noqa: E501

        :param incident_type: The incident_type of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._incident_type = incident_type

    @property
    def incident_status(self):
        """Gets the incident_status of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Only include process instances which have an incident in status either open or resolved. To get all process instances, use the query parameter withIncidents.  # noqa: E501

        :return: The incident_status of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._incident_status

    @incident_status.setter
    def incident_status(self, incident_status):
        """Sets the incident_status of this HistoricProcessInstanceQueryDto.

        Only include process instances which have an incident in status either open or resolved. To get all process instances, use the query parameter withIncidents.  # noqa: E501

        :param incident_status: The incident_status of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["open", "resolved"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and incident_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `incident_status` ({0}), must be one of {1}"  # noqa: E501
                .format(incident_status, allowed_values)
            )

        self._incident_status = incident_status

    @property
    def incident_message(self):
        """Gets the incident_message of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by the incident message. Exact match.  # noqa: E501

        :return: The incident_message of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._incident_message

    @incident_message.setter
    def incident_message(self, incident_message):
        """Sets the incident_message of this HistoricProcessInstanceQueryDto.

        Filter by the incident message. Exact match.  # noqa: E501

        :param incident_message: The incident_message of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._incident_message = incident_message

    @property
    def incident_message_like(self):
        """Gets the incident_message_like of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by the incident message that the parameter is a substring of.  # noqa: E501

        :return: The incident_message_like of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._incident_message_like

    @incident_message_like.setter
    def incident_message_like(self, incident_message_like):
        """Sets the incident_message_like of this HistoricProcessInstanceQueryDto.

        Filter by the incident message that the parameter is a substring of.  # noqa: E501

        :param incident_message_like: The incident_message_like of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._incident_message_like = incident_message_like

    @property
    def started_before(self):
        """Gets the started_before of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that were started before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The started_before of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._started_before

    @started_before.setter
    def started_before(self, started_before):
        """Sets the started_before of this HistoricProcessInstanceQueryDto.

        Restrict to instances that were started before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param started_before: The started_before of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: datetime
        """

        self._started_before = started_before

    @property
    def started_after(self):
        """Gets the started_after of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that were started after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The started_after of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._started_after

    @started_after.setter
    def started_after(self, started_after):
        """Sets the started_after of this HistoricProcessInstanceQueryDto.

        Restrict to instances that were started after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param started_after: The started_after of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: datetime
        """

        self._started_after = started_after

    @property
    def finished_before(self):
        """Gets the finished_before of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that were finished before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The finished_before of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._finished_before

    @finished_before.setter
    def finished_before(self, finished_before):
        """Sets the finished_before of this HistoricProcessInstanceQueryDto.

        Restrict to instances that were finished before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param finished_before: The finished_before of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: datetime
        """

        self._finished_before = finished_before

    @property
    def finished_after(self):
        """Gets the finished_after of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that were finished after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The finished_after of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._finished_after

    @finished_after.setter
    def finished_after(self, finished_after):
        """Sets the finished_after of this HistoricProcessInstanceQueryDto.

        Restrict to instances that were finished after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param finished_after: The finished_after of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: datetime
        """

        self._finished_after = finished_after

    @property
    def executed_activity_after(self):
        """Gets the executed_activity_after of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that executed an activity after the given date (inclusive). By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The executed_activity_after of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._executed_activity_after

    @executed_activity_after.setter
    def executed_activity_after(self, executed_activity_after):
        """Sets the executed_activity_after of this HistoricProcessInstanceQueryDto.

        Restrict to instances that executed an activity after the given date (inclusive). By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param executed_activity_after: The executed_activity_after of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: datetime
        """

        self._executed_activity_after = executed_activity_after

    @property
    def executed_activity_before(self):
        """Gets the executed_activity_before of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that executed an activity before the given date (inclusive). By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The executed_activity_before of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._executed_activity_before

    @executed_activity_before.setter
    def executed_activity_before(self, executed_activity_before):
        """Sets the executed_activity_before of this HistoricProcessInstanceQueryDto.

        Restrict to instances that executed an activity before the given date (inclusive). By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param executed_activity_before: The executed_activity_before of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: datetime
        """

        self._executed_activity_before = executed_activity_before

    @property
    def executed_job_after(self):
        """Gets the executed_job_after of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that executed an job after the given date (inclusive). By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The executed_job_after of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._executed_job_after

    @executed_job_after.setter
    def executed_job_after(self, executed_job_after):
        """Sets the executed_job_after of this HistoricProcessInstanceQueryDto.

        Restrict to instances that executed an job after the given date (inclusive). By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param executed_job_after: The executed_job_after of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: datetime
        """

        self._executed_job_after = executed_job_after

    @property
    def executed_job_before(self):
        """Gets the executed_job_before of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that executed an job before the given date (inclusive). By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The executed_job_before of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._executed_job_before

    @executed_job_before.setter
    def executed_job_before(self, executed_job_before):
        """Sets the executed_job_before of this HistoricProcessInstanceQueryDto.

        Restrict to instances that executed an job before the given date (inclusive). By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param executed_job_before: The executed_job_before of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: datetime
        """

        self._executed_job_before = executed_job_before

    @property
    def started_by(self):
        """Gets the started_by of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Only include process instances that were started by the given user.  # noqa: E501

        :return: The started_by of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._started_by

    @started_by.setter
    def started_by(self, started_by):
        """Sets the started_by of this HistoricProcessInstanceQueryDto.

        Only include process instances that were started by the given user.  # noqa: E501

        :param started_by: The started_by of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._started_by = started_by

    @property
    def super_process_instance_id(self):
        """Gets the super_process_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict query to all process instances that are sub process instances of the given process instance. Takes a process instance id.  # noqa: E501

        :return: The super_process_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._super_process_instance_id

    @super_process_instance_id.setter
    def super_process_instance_id(self, super_process_instance_id):
        """Sets the super_process_instance_id of this HistoricProcessInstanceQueryDto.

        Restrict query to all process instances that are sub process instances of the given process instance. Takes a process instance id.  # noqa: E501

        :param super_process_instance_id: The super_process_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._super_process_instance_id = super_process_instance_id

    @property
    def sub_process_instance_id(self):
        """Gets the sub_process_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict query to one process instance that has a sub process instance with the given id.  # noqa: E501

        :return: The sub_process_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._sub_process_instance_id

    @sub_process_instance_id.setter
    def sub_process_instance_id(self, sub_process_instance_id):
        """Sets the sub_process_instance_id of this HistoricProcessInstanceQueryDto.

        Restrict query to one process instance that has a sub process instance with the given id.  # noqa: E501

        :param sub_process_instance_id: The sub_process_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._sub_process_instance_id = sub_process_instance_id

    @property
    def super_case_instance_id(self):
        """Gets the super_case_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict query to all process instances that are sub process instances of the given case instance. Takes a case instance id.  # noqa: E501

        :return: The super_case_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._super_case_instance_id

    @super_case_instance_id.setter
    def super_case_instance_id(self, super_case_instance_id):
        """Sets the super_case_instance_id of this HistoricProcessInstanceQueryDto.

        Restrict query to all process instances that are sub process instances of the given case instance. Takes a case instance id.  # noqa: E501

        :param super_case_instance_id: The super_case_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._super_case_instance_id = super_case_instance_id

    @property
    def sub_case_instance_id(self):
        """Gets the sub_case_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict query to one process instance that has a sub case instance with the given id.  # noqa: E501

        :return: The sub_case_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._sub_case_instance_id

    @sub_case_instance_id.setter
    def sub_case_instance_id(self, sub_case_instance_id):
        """Sets the sub_case_instance_id of this HistoricProcessInstanceQueryDto.

        Restrict query to one process instance that has a sub case instance with the given id.  # noqa: E501

        :param sub_case_instance_id: The sub_case_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._sub_case_instance_id = sub_case_instance_id

    @property
    def case_instance_id(self):
        """Gets the case_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict query to all process instances that are sub process instances of the given case instance. Takes a case instance id.  # noqa: E501

        :return: The case_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._case_instance_id

    @case_instance_id.setter
    def case_instance_id(self, case_instance_id):
        """Sets the case_instance_id of this HistoricProcessInstanceQueryDto.

        Restrict query to all process instances that are sub process instances of the given case instance. Takes a case instance id.  # noqa: E501

        :param case_instance_id: The case_instance_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._case_instance_id = case_instance_id

    @property
    def tenant_id_in(self):
        """Gets the tenant_id_in of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Filter by a list of tenant ids. A process instance must have one of the given tenant ids. Must be a JSON array of `Strings`  # noqa: E501

        :return: The tenant_id_in of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._tenant_id_in

    @tenant_id_in.setter
    def tenant_id_in(self, tenant_id_in):
        """Sets the tenant_id_in of this HistoricProcessInstanceQueryDto.

        Filter by a list of tenant ids. A process instance must have one of the given tenant ids. Must be a JSON array of `Strings`  # noqa: E501

        :param tenant_id_in: The tenant_id_in of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: list[str]
        """

        self._tenant_id_in = tenant_id_in

    @property
    def without_tenant_id(self):
        """Gets the without_tenant_id of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Only include historic process instances which belong to no tenant. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :return: The without_tenant_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._without_tenant_id

    @without_tenant_id.setter
    def without_tenant_id(self, without_tenant_id):
        """Sets the without_tenant_id of this HistoricProcessInstanceQueryDto.

        Only include historic process instances which belong to no tenant. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :param without_tenant_id: The without_tenant_id of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._without_tenant_id = without_tenant_id

    @property
    def executed_activity_id_in(self):
        """Gets the executed_activity_id_in of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that executed an activity with one of given ids. Must be a JSON array of `Strings`  # noqa: E501

        :return: The executed_activity_id_in of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._executed_activity_id_in

    @executed_activity_id_in.setter
    def executed_activity_id_in(self, executed_activity_id_in):
        """Sets the executed_activity_id_in of this HistoricProcessInstanceQueryDto.

        Restrict to instances that executed an activity with one of given ids. Must be a JSON array of `Strings`  # noqa: E501

        :param executed_activity_id_in: The executed_activity_id_in of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: list[str]
        """

        self._executed_activity_id_in = executed_activity_id_in

    @property
    def active_activity_id_in(self):
        """Gets the active_activity_id_in of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that have an active activity with one of given ids. Must be a JSON array of `Strings`  # noqa: E501

        :return: The active_activity_id_in of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._active_activity_id_in

    @active_activity_id_in.setter
    def active_activity_id_in(self, active_activity_id_in):
        """Sets the active_activity_id_in of this HistoricProcessInstanceQueryDto.

        Restrict to instances that have an active activity with one of given ids. Must be a JSON array of `Strings`  # noqa: E501

        :param active_activity_id_in: The active_activity_id_in of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: list[str]
        """

        self._active_activity_id_in = active_activity_id_in

    @property
    def active(self):
        """Gets the active of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that are active.  # noqa: E501

        :return: The active of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this HistoricProcessInstanceQueryDto.

        Restrict to instances that are active.  # noqa: E501

        :param active: The active of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def suspended(self):
        """Gets the suspended of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that are suspended.  # noqa: E501

        :return: The suspended of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._suspended

    @suspended.setter
    def suspended(self, suspended):
        """Sets the suspended of this HistoricProcessInstanceQueryDto.

        Restrict to instances that are suspended.  # noqa: E501

        :param suspended: The suspended of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._suspended = suspended

    @property
    def completed(self):
        """Gets the completed of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that are completed.  # noqa: E501

        :return: The completed of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._completed

    @completed.setter
    def completed(self, completed):
        """Sets the completed of this HistoricProcessInstanceQueryDto.

        Restrict to instances that are completed.  # noqa: E501

        :param completed: The completed of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._completed = completed

    @property
    def externally_terminated(self):
        """Gets the externally_terminated of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that are externallyTerminated.  # noqa: E501

        :return: The externally_terminated of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._externally_terminated

    @externally_terminated.setter
    def externally_terminated(self, externally_terminated):
        """Sets the externally_terminated of this HistoricProcessInstanceQueryDto.

        Restrict to instances that are externallyTerminated.  # noqa: E501

        :param externally_terminated: The externally_terminated of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._externally_terminated = externally_terminated

    @property
    def internally_terminated(self):
        """Gets the internally_terminated of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Restrict to instances that are internallyTerminated.  # noqa: E501

        :return: The internally_terminated of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._internally_terminated

    @internally_terminated.setter
    def internally_terminated(self, internally_terminated):
        """Sets the internally_terminated of this HistoricProcessInstanceQueryDto.

        Restrict to instances that are internallyTerminated.  # noqa: E501

        :param internally_terminated: The internally_terminated of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._internally_terminated = internally_terminated

    @property
    def variables(self):
        """Gets the variables of this HistoricProcessInstanceQueryDto.  # noqa: E501

        A JSON array to only include process instances that have/had variables with certain values. The array consists of objects with the three properties `name`, `operator` and `value`. `name` (`String`) is the variable name, `operator` (`String`) is the comparison operator to be used and `value` the variable value.  Value may be `String`, `Number` or `Boolean`.  Valid operator values are: `eq` - equal to; `neq` - not equal to; `gt` - greater than; `gteq` - greater than or equal to; `lt` - lower than; `lteq` - lower than or equal to; `like`.   # noqa: E501

        :return: The variables of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: list[VariableQueryParameterDto]
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """Sets the variables of this HistoricProcessInstanceQueryDto.

        A JSON array to only include process instances that have/had variables with certain values. The array consists of objects with the three properties `name`, `operator` and `value`. `name` (`String`) is the variable name, `operator` (`String`) is the comparison operator to be used and `value` the variable value.  Value may be `String`, `Number` or `Boolean`.  Valid operator values are: `eq` - equal to; `neq` - not equal to; `gt` - greater than; `gteq` - greater than or equal to; `lt` - lower than; `lteq` - lower than or equal to; `like`.   # noqa: E501

        :param variables: The variables of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: list[VariableQueryParameterDto]
        """

        self._variables = variables

    @property
    def variable_names_ignore_case(self):
        """Gets the variable_names_ignore_case of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Match all variable names provided in variables case-insensitively. If set to `true` variableName and variablename are treated as equal.  # noqa: E501

        :return: The variable_names_ignore_case of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._variable_names_ignore_case

    @variable_names_ignore_case.setter
    def variable_names_ignore_case(self, variable_names_ignore_case):
        """Sets the variable_names_ignore_case of this HistoricProcessInstanceQueryDto.

        Match all variable names provided in variables case-insensitively. If set to `true` variableName and variablename are treated as equal.  # noqa: E501

        :param variable_names_ignore_case: The variable_names_ignore_case of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._variable_names_ignore_case = variable_names_ignore_case

    @property
    def variable_values_ignore_case(self):
        """Gets the variable_values_ignore_case of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Match all variable values provided in variables case-insensitively. If set to `true` variableValue and variablevalue are treated as equal.  # noqa: E501

        :return: The variable_values_ignore_case of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._variable_values_ignore_case

    @variable_values_ignore_case.setter
    def variable_values_ignore_case(self, variable_values_ignore_case):
        """Sets the variable_values_ignore_case of this HistoricProcessInstanceQueryDto.

        Match all variable values provided in variables case-insensitively. If set to `true` variableValue and variablevalue are treated as equal.  # noqa: E501

        :param variable_values_ignore_case: The variable_values_ignore_case of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._variable_values_ignore_case = variable_values_ignore_case

    @property
    def or_queries(self):
        """Gets the or_queries of this HistoricProcessInstanceQueryDto.  # noqa: E501

        A JSON array of nested historic process instance queries with OR semantics.  A process instance matches a nested query if it fulfills at least one of the query's predicates.  With multiple nested queries, a process instance must fulfill at least one predicate of each query ([Conjunctive Normal Form](https://en.wikipedia.org/wiki/Conjunctive_normal_form)).  All process instance query properties can be used except for: `sorting`  See the [User Guide](https://docs.camunda.org/manual/7.14/user-guide/process-engine/process-engine-api/#or-queries) for more information about OR queries.  # noqa: E501

        :return: The or_queries of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: list[HistoricProcessInstanceQueryDto]
        """
        return self._or_queries

    @or_queries.setter
    def or_queries(self, or_queries):
        """Sets the or_queries of this HistoricProcessInstanceQueryDto.

        A JSON array of nested historic process instance queries with OR semantics.  A process instance matches a nested query if it fulfills at least one of the query's predicates.  With multiple nested queries, a process instance must fulfill at least one predicate of each query ([Conjunctive Normal Form](https://en.wikipedia.org/wiki/Conjunctive_normal_form)).  All process instance query properties can be used except for: `sorting`  See the [User Guide](https://docs.camunda.org/manual/7.14/user-guide/process-engine/process-engine-api/#or-queries) for more information about OR queries.  # noqa: E501

        :param or_queries: The or_queries of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: list[HistoricProcessInstanceQueryDto]
        """

        self._or_queries = or_queries

    @property
    def sorting(self):
        """Gets the sorting of this HistoricProcessInstanceQueryDto.  # noqa: E501

        Apply sorting of the result  # noqa: E501

        :return: The sorting of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :rtype: list[HistoricProcessInstanceQueryDtoSorting]
        """
        return self._sorting

    @sorting.setter
    def sorting(self, sorting):
        """Sets the sorting of this HistoricProcessInstanceQueryDto.

        Apply sorting of the result  # noqa: E501

        :param sorting: The sorting of this HistoricProcessInstanceQueryDto.  # noqa: E501
        :type: list[HistoricProcessInstanceQueryDtoSorting]
        """

        self._sorting = sorting

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoricProcessInstanceQueryDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HistoricProcessInstanceQueryDto):
            return True

        return self.to_dict() != other.to_dict()
